XTraceback is a verbose Python traceback formatter with support for variable
expansion and syntax highlighting. It is intended both as a development tool
and as an aide to post-mortem debugging.

.. image:: https://secure.travis-ci.org/0compute/xtraceback.png?branch=master
    :target: http://travis-ci.org/0compute/xtraceback

Documentation is published at `read the docs`_.

.. _read the docs: https://xtraceback.readthedocs.org/en/latest/
